@@ -45,7 +45,7 @@ impl<'a> Descriptor<'a> {
     /// Returns `None` if
     ///   * the slice length is not at least 2.
     ///   * the `bLength` field (first byte) is greater than the slice length.
-    pub fn new(buf: &[u8]) -> Option<Descriptor> {
+    pub fn new(buf: &[u8]) -> Option<Descriptor<'_>> {
         if buf.len() >= 2 && buf.len() >= buf[0] as usize {
             Some(Descriptor(buf))
         } else {
@@ -352,7 +352,7 @@ impl<'a> ConfigurationDescriptor<'a> {
     /// one from your own descriptor bytes for tests.
     ///
     /// This ignores any trailing data after the length specified in `wTotalLen`.
-    pub fn new(buf: &[u8]) -> Option<ConfigurationDescriptor> {
+    pub fn new(buf: &[u8]) -> Option<ConfigurationDescriptor<'_>> {
         if buf.len() < DESCRIPTOR_LEN_CONFIGURATION as usize {
             if !buf.is_empty() {
                 warn!(
@@ -708,7 +708,7 @@ pub enum TransferType {
 #[allow(unused)]
 pub(crate) fn parse_concatenated_config_descriptors(
     mut buf: &[u8],
-) -> impl Iterator<Item = ConfigurationDescriptor> {
+) -> impl Iterator<Item = ConfigurationDescriptor<'_>> {
     iter::from_fn(move || {
         let desc = ConfigurationDescriptor::new(buf)?;
         buf = &buf[desc.0.len()..];
@@ -898,7 +898,7 @@ fn test_dell_webcam() {
 
         // VideoControl
         0x09, 0x24, 0x03, 0x05, 0x01, 0x01, 0x00, 0x04, 0x00,
-        
+
         // VideoControl
         0x1a, 0x24, 0x06, 0x03, 0x70, 0x33, 0xf0, 0x28, 0x11, 0x63, 0x2e, 0x4a,
         0xba, 0x2c, 0x68, 0x90, 0xeb, 0x33, 0x40, 0x16, 0x08, 0x01, 0x02, 0x01,
@@ -908,66 +908,66 @@ fn test_dell_webcam() {
         0x1a, 0x24, 0x06, 0x04, 0xc3, 0x85, 0xb8, 0x0f, 0xc2, 0x68, 0x47, 0x45,
         0x90, 0xf7, 0x8f, 0x47, 0x57, 0x9d, 0x95, 0xfc, 0x08, 0x01, 0x03, 0x01,
         0x0f, 0x00,
-        
+
         // VideoControl
         0x12, 0x24, 0x02, 0x01, 0x01, 0x02, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
         0x00, 0x00, 0x03, 0x0e, 0x00, 0x20,
-        
+
         // VideoControl
         0x0b, 0x24, 0x05, 0x02, 0x01, 0x00, 0x00, 0x02, 0x7f, 0x17, 0x00,
-        
+
         // Endpoint
         0x07, 0x05, 0x83, 0x03, 0x10, 0x00, 0x06,
-        
+
         // Class-specific endpoint info
         0x05, 0x25, 0x03, 0x80, 0x00,
-        
+
         // Interface
         0x09, 0x04, 0x01, 0x00, 0x00, 0x0e, 0x02, 0x00, 0x00,
-        
+
         // Video Streaming
         0x0f, 0x24, 0x01, 0x02, 0x85, 0x01, 0x81, 0x00, 0x05, 0x00, 0x00, 0x00,
         0x01, 0x00, 0x00,
-        
+
         // Video streaming
         0x0b, 0x24, 0x06, 0x01, 0x05, 0x00, 0x01, 0x00, 0x00, 0x00, 0x00,
-        
+
         // Video streaming (12 more omitted)
         0x06, 0x24, 0x0d, 0x01, 0x01, 0x04,
-        
+
         // Interface
         0x09, 0x04, 0x01, 0x01, 0x01, 0x0e, 0x02, 0x00, 0x00,
-        
+
         // Endpoint
         0x07, 0x05, 0x81, 0x05, 0x80, 0x00, 0x01,
-        
+
         // Interface
         0x09, 0x04, 0x01, 0x02, 0x01, 0x0e, 0x02, 0x00, 0x00,
-        
+
         // Endpoint
         0x07, 0x05, 0x81, 0x05, 0x00, 0x01, 0x01,
-        
+
         // Interface
         0x09, 0x04, 0x01, 0x03, 0x01, 0x0e, 0x02, 0x00, 0x00,
-        
+
         // Endpoint
         0x07, 0x05, 0x81, 0x05, 0x20, 0x03, 0x01,
-        
+
         // Interface
         0x09, 0x04, 0x01, 0x04, 0x01, 0x0e, 0x02, 0x00, 0x00,
-        
+
         // Endpoint
         0x07, 0x05, 0x81, 0x05, 0x20, 0x0b, 0x01,
-        
+
         // Interface
         0x09, 0x04, 0x01, 0x05, 0x01, 0x0e, 0x02, 0x00, 0x00,
-        
+
         // Endpoint
         0x07, 0x05, 0x81, 0x05, 0x20, 0x13, 0x01,
-        
+
         // Interface
         0x09, 0x04, 0x01, 0x06, 0x01, 0x0e, 0x02, 0x00, 0x00,
-        
+
         // Endpoint
         0x07, 0x05, 0x81, 0x05, 0x00, 0x14, 0x01
     ]);
@@ -1005,7 +1005,7 @@ fn test_dell_webcam() {
     assert_eq!(endpoint.max_packet_size(), 16);
 
     assert_eq!(endpoint.descriptors().next().unwrap().descriptor_type(), 0x25);
-    
+
     assert!(endpoints.next().is_none());
     assert!(alts.next().is_none());
 
